==========
picoserver
==========


.. image:: https://img.shields.io/pypi/v/picoserver.svg
        :target: https://pypi.python.org/pypi/picoserver

.. image:: https://img.shields.io/travis/matthiaszeller/picoserver.svg
        :target: https://travis-ci.com/matthiaszeller/picoserver

.. image:: https://readthedocs.org/projects/picoserver/badge/?version=latest
        :target: https://picoserver.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Client-server package to remotely control a Raspberrypi Pico W


* Free software: MIT license
* Documentation: https://picoserver.readthedocs.io.
